@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 #
-# $Id: whereami.pl,v 1.28 2004/04/21 21:38:25 andrew Exp $
+# $Id: whereami.pl,v 1.29 2005/02/12 23:28:24 andrew Exp $
 #
 # by Andrew McMillan, Catalyst IT Ltd, (c) 2001,2002 licensed
 # for use under the Gnu GPL version 2
@@ -75,7 +75,7 @@ print "BaseDir: $basedir\n" if ( $debug );
 $ENV{'BASEDIR'} =$basedir;
 $ENV{'STATEDIR'} =$statedir;
 $ENV{'LOCKDIR'} =$lockdir;
-$ENV{'PATH'} = "$scriptbase/tests:$scriptbase:/bin:/usr/bin:/sbin:/usr/sbin:$basedir/tests";
+$ENV{'PATH'} = "$scriptbase/tests:$scriptbase:/bin:/usr/bin:/sbin:/usr/sbin:$basedir/tests;/usr/local/share/whereami";
 $ENV{'DEBUGWHEREAMI'} = "1" if ( $debug || $scriptdebugging );
 
 
